#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_graphene-django-graphiql-static
------------

Tests for `graphene-django-graphiql-static` models module.
"""

from django.test import TestCase

from graphene_django_graphiql_static import models


class TestGraphene_django_graphiql_static(TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass
